Module config

Module config 

Various configuration options to control Lofty

Structs

GlobalOptions
Options that control all interactions with Lofty for the current thread
ParseOptions
Options to control how Lofty parses a file
WriteOptions
Options to control how Lofty writes to a file

Enums

ParsingMode
The parsing strictness mode

Functions

apply_global_options
Applies the given GlobalOptions to the current thread