Contains the errors that can arise within Lofty
The primary error is LoftyError. The type of error is determined by ErrorKind,
which can be extended at any time.
Structs
- An error that arises while decoding a file
- An error that arises while encoding a file
- An error that arises while interacting with an ID3v2 tag
- Errors that could occur within Lofty
Enums
- The types of errors that can occur
- The types of errors that can occur while interacting with ID3v2 tags
Type Aliases
- Alias for
Result<T, LoftyError>