BoundTaggedFile

Struct BoundTaggedFile 

pub struct BoundTaggedFile<F> { /* private fields */ }
A variant of TaggedFile that holds a handle to its original FileLike buffer, and reflects changes such as tag removals.

For example:

use lofty::config::WriteOptions;
use lofty::file::{AudioFile, TaggedFileExt};
use lofty::tag::{Tag, TagType};

// We create an empty tag
let tag = Tag::new(TagType::Id3v2);

let mut tagged_file = lofty::read_from_path(path)?;

// Push our empty tag into the TaggedFile
tagged_file.insert_tag(tag);

// After saving, our file still "contains" the ID3v2 tag, but if we were to read
// "foo.mp3", it would not have an ID3v2 tag. Lofty does not write empty tags, but this
// change will not be reflected in `TaggedFile`.
tagged_file.save_to_path("foo.mp3", WriteOptions::default())?;
assert!(tagged_file.contains_tag_type(TagType::Id3v2));

However, when using BoundTaggedFile:

use lofty::config::{ParseOptions, WriteOptions};
use lofty::file::{AudioFile, BoundTaggedFile, TaggedFileExt};
use lofty::tag::{Tag, TagType};
use std::fs::OpenOptions;

// We create an empty tag
let tag = Tag::new(TagType::Id3v2);

// We'll need to open our file for reading *and* writing
let file = OpenOptions::new().read(true).write(true).open(path)?;
let parse_options = ParseOptions::new();

let mut bound_tagged_file = BoundTaggedFile::read_from(file, parse_options)?;

// Push our empty tag into the TaggedFile
bound_tagged_file.insert_tag(tag);

// Now when saving, we no longer have to specify a path, and the tags in the `BoundTaggedFile`
// reflect those in the actual file on disk.
bound_tagged_file.save(WriteOptions::default())?;
assert!(!bound_tagged_file.contains_tag_type(TagType::Id3v2));

Implementations

Source

impl<F> BoundTaggedFile<F>

pub fn into_inner(self) -> F

Consume this tagged file and return the internal file “buffer”. This allows you to reuse the internal file.

Any changes that haven’t been commited will be discarded once you call this function.

Source

impl<F: FileLike> BoundTaggedFile<F>
where LoftyError: From<<F as Truncate>::Error> + From<<F as Length>::Error>,

pub fn read_from(file: F, parse_options: ParseOptions) -> Result<Self>

Create a new BoundTaggedFile

Errors

See AudioFile::read_from

Examples
use lofty::config::ParseOptions;
use lofty::file::{AudioFile, BoundTaggedFile, TaggedFileExt};
use lofty::tag::{Tag, TagType};
use std::fs::OpenOptions;

// We'll need to open our file for reading *and* writing
let file = OpenOptions::new().read(true).write(true).open(path)?;
let parse_options = ParseOptions::new();

let bound_tagged_file = BoundTaggedFile::read_from(file, parse_options)?;
pub fn save(&mut self, write_options: WriteOptions) -> Result<()>

Save the tags to the file stored internally

Errors

See TaggedFile::save_to

Examples
use lofty::config::{ParseOptions, WriteOptions};
use lofty::file::{AudioFile, BoundTaggedFile, TaggedFileExt};
use lofty::tag::{Tag, TagType};
use std::fs::OpenOptions;

// We'll need to open our file for reading *and* writing
let file = OpenOptions::new().read(true).write(true).open(path)?;
let parse_options = ParseOptions::new();

let mut bound_tagged_file = BoundTaggedFile::read_from(file, parse_options)?;

// Do some work to the tags...

// This will save the tags to the file we provided to `read_from`
bound_tagged_file.save(WriteOptions::default())?;