pub enum Link {
VeryLowStartOrEnd,
LoudEnd,
LoudStart,
LoudStartAndEnd,
}Expand description
Volume description for the start and end of the title
Variants
VeryLowStartOrEnd
Title starts or ends with a very low level (no live or classical genre titles)
LoudEnd
Title ends loudly
LoudStart
Title starts loudly
LoudStartAndEnd
Title starts loudly and ends loudly
Implementations